@@ -1,4 +1,4 @@
-/* $Id: nss.c 82 2005-08-05 23:51:50Z lennart $ */
+/* $Id: nss.c 87 2005-11-20 00:45:03Z lennart $ */
 
 /***
     This file is part of nss-mdns.
@@ -8,7 +8,7 @@
     by the Free Software Foundation; either version 2 of the License,
     or (at your option) any later version.
  
-    nss-mdns is distributed in the hope that it will be useful, but
+    nss-mdns is distributed in the hope that it will be useful, but1
     WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
     General Public License for more details.
@@ -456,6 +456,9 @@ enum nss_status _nss_mdns_gethostbyname2_r(
     result->h_addrtype = af;
     result->h_length = address_length;
     
+    if (idx%sizeof(char*))
+        idx+=(sizeof(char*)-idx%sizeof(char*)); /* Align on 32 bit boundary */
+    
     /* Check if there's enough space for the addresses */
     if (buflen < idx+u.data_len+sizeof(char*)*(u.count+1)) {
         *errnop = ERANGE;
